@@ -143,11 +143,16 @@ class PubSubManager(BasePubSubManager):
 
     async def _socket_reader(self, sock: Socket) -> None:
         """Waits and dispatches messages as long as the socket is open"""
-        while not sock.closed:
-            # LOGGER.debug("waiting message on {}".format(sock))
-            msgparts = await sock.recv_multipart()
-            # LOGGER.debug("got message on {}".format(sock))
-            await self.raw_zmq_callback_async(sock, msgparts)
+        try:
+            while not sock.closed:
+                # LOGGER.debug("waiting message on {}".format(sock))
+                msgparts = await sock.recv_multipart()
+                # LOGGER.debug("got message on {}".format(sock))
+                await self.raw_zmq_callback_async(sock, msgparts)
+            LOGGER.debug("socket closed")
+        except asyncio.CancelledError:
+            # Handle cancellations gracefully
+            LOGGER.debug("cancelled")
 
     async def publish_async(
         self, msg: PubSubMessage, sockdef: Union[ZMQSocket, ZMQSocketUrisInputTypes, None] = None
@@ -177,7 +182,11 @@ class PubSubManager(BasePubSubManager):
         def send_task_done(task: "asyncio.Task[Any]") -> None:
             """done callback for the send task"""
             # raise exception if there was any
-            task.result()
+            try:
+                task.result()
+            except asyncio.CancelledError:
+                # Handle cancellations gracefully
+                LOGGER.warning("task {} was cancelled for some reason, it should not have been".format(task))
 
         task.add_done_callback(send_task_done)
 
